Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/fullscreen/UIMachineLogicFullscreen.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/fullscreen/UIMachineLogicFullscreen.cpp	(revision 50775)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/fullscreen/UIMachineLogicFullscreen.cpp	(revision 50776)
@@ -632,6 +632,14 @@
                 emit sigNotifyAboutNativeFullscreenShouldBeEntered(pMachineWindow);
             }
-            /* Else make sure that window is hidden: */
-            else pMachineWindow->showInNecessaryMode();
+            /* If that window
+             * is shown while shouldn't: */
+            else if (pMachineWindow->isVisible())
+            {
+                /* Else make sure that window is hidden: */
+                pMachineWindow->showInNecessaryMode();
+
+                /* Fade to normal: */
+                fadeToNormal();
+            }
         }
         /* Validate window which is in fullscreen: */
